@@ -170,7 +170,7 @@ impl Expr {
             result.extend(right.get_required_fields());
         }
 
-        if let Some( field) = self.field {
+        if let Some(field) = self.field {
             result.insert(field);
         }
 
@@ -190,7 +190,7 @@ impl Expr {
     fn contains_numeric_field(expr: &Expr) -> bool {
         let field = match expr.field {
             Some(ref field) => field.is_numeric_field(),
-            None => false
+            None => false,
         };
 
         if field {
@@ -199,19 +199,17 @@ impl Expr {
 
         let function = match expr.function {
             Some(ref function) => function.is_numeric_function(),
-            None => false
+            None => false,
         };
 
         if function {
             return true;
         }
 
-        let left = match expr.left {
-            Some(ref left) => Self::contains_numeric_field(&left),
-            None => false
-        };
-
-        left
+        match expr.left {
+            Some(ref left) => Self::contains_numeric_field(left),
+            None => false,
+        }
     }
 
     pub fn contains_datetime(&self) -> bool {
@@ -221,19 +219,17 @@ impl Expr {
     fn contains_datetime_field(expr: &Expr) -> bool {
         let field = match expr.field {
             Some(ref field) => field.is_datetime_field(),
-            None => false
+            None => false,
         };
 
         if field {
             return true;
         }
 
-        let left = match expr.left {
-            Some(ref left) => Self::contains_datetime_field(&left),
-            None => false
-        };
-
-        left
+        match expr.left {
+            Some(ref left) => Self::contains_datetime_field(left),
+            None => false,
+        }
     }
 
     pub fn contains_colorized(&self) -> bool {
@@ -247,19 +243,17 @@ impl Expr {
 
         let field = match expr.field {
             Some(ref field) => field.is_colorized_field(),
-            None => false
+            None => false,
         };
 
         if field {
             return true;
         }
 
-        let left = match expr.left {
-            Some(ref left) => Self::contains_colorized_field(&left),
-            None => false
-        };
-
-        left
+        match expr.left {
+            Some(ref left) => Self::contains_colorized_field(left),
+            None => false,
+        }
     }
 }
 
@@ -287,7 +281,7 @@ impl Display for Expr {
         }
 
         if let Some(ref val) = self.val {
-            fmt.write_str(&val)?;
+            fmt.write_str(val)?;
         }
 
         if let Some(ref right) = self.right {
