@@ -1,5 +1,6 @@
-#[macro_use]
-extern crate lazy_static;
+//! The entry point of the program
+//! Handles the command line arguments parsing
+
 #[macro_use]
 extern crate serde_derive;
 #[cfg(all(unix, feature = "users"))]
@@ -8,7 +9,7 @@ extern crate uzers;
 extern crate xattr;
 
 use std::env;
-use std::io::{IsTerminal, stdout};
+use std::io::{stdout, IsTerminal};
 use std::path::PathBuf;
 use std::process::ExitCode;
 #[cfg(feature = "update-notifications")]
@@ -42,15 +43,17 @@ use crate::util::error_message;
 use crate::util::str_to_bool;
 
 fn main() -> ExitCode {
+    let default_config = Config::default();
+
     let mut config = match Config::new() {
         Ok(cnf) => cnf,
         Err(err) => {
             eprintln!("{}", err);
-            Config::default()
+            default_config.clone()
         }
     };
 
-    let env_var_value = std::env::var("NO_COLOR").ok().unwrap_or(String::new());
+    let env_var_value = std::env::var("NO_COLOR").ok().unwrap_or_default();
     let env_no_color = str_to_bool(&env_var_value).unwrap_or(false);
     let mut no_color = env_no_color || config.no_color.unwrap_or(false);
 
@@ -61,7 +64,7 @@ fn main() -> ExitCode {
             let win_init_ok = match res {
                 Ok(()) => true,
                 Err(203) => true,
-                _ => false
+                _ => false,
             };
             no_color = !win_init_ok;
         }
@@ -83,8 +86,12 @@ fn main() -> ExitCode {
         return ExitCode::SUCCESS;
     }
 
-    if first_arg.contains("help") || first_arg.starts_with("-h") || first_arg.starts_with("/?") || first_arg.starts_with("/h") {
-        usage_info(config, no_color);
+    if first_arg.contains("help")
+        || first_arg.starts_with("-h")
+        || first_arg.starts_with("/?")
+        || first_arg.starts_with("/h")
+    {
+        usage_info(config, default_config, no_color);
         return ExitCode::SUCCESS;
     }
 
@@ -93,15 +100,21 @@ fn main() -> ExitCode {
     loop {
         if first_arg.contains("nocolor") || first_arg.contains("no-color") {
             no_color = true;
-        } else if first_arg.starts_with("-i") || first_arg.starts_with("--i") || first_arg.starts_with("/i") {
+        } else if first_arg.starts_with("-i")
+            || first_arg.starts_with("--i")
+            || first_arg.starts_with("/i")
+        {
             interactive = true;
-        } else if first_arg.starts_with("-c") || first_arg.starts_with("--config") || first_arg.starts_with("/c") {
+        } else if first_arg.starts_with("-c")
+            || first_arg.starts_with("--config")
+            || first_arg.starts_with("/c")
+        {
             let config_path = args[1].to_ascii_lowercase();
             config = match Config::from(PathBuf::from(&config_path)) {
                 Ok(cnf) => cnf,
                 Err(err) => {
                     eprintln!("{}", err);
-                    Config::default()
+                    default_config.clone()
                 }
             };
 
@@ -129,30 +142,31 @@ fn main() -> ExitCode {
 
     if interactive {
         match DefaultEditor::new() {
-            Ok(mut rl) => {
-                loop {
-                    let readline = rl.readline("query> ");
-                    match readline {
-                        Ok(cmd) if cmd.to_ascii_lowercase().trim() == "quit" || cmd.to_ascii_lowercase().trim() == "exit" => {
-                            break
-                        },
-                        Ok(query) => {
-                            let _ = rl.add_history_entry(query.as_str());
-                            exec_search(query, &mut config, no_color);
-                        },
-                        Err(ReadlineError::Interrupted) => {
-                            println!("CTRL-C");
-                            break
-                        },
-                        Err(ReadlineError::Eof) => {
-                            println!("CTRL-D");
-                            break
-                        },
-                        Err(err) => {
-                            let err = format!("{:?}", err);
-                            error_message("input", &err);
-                            break
-                        }
+            Ok(mut rl) => loop {
+                let readline = rl.readline("query> ");
+                match readline {
+                    Ok(cmd)
+                        if cmd.to_ascii_lowercase().trim() == "quit"
+                            || cmd.to_ascii_lowercase().trim() == "exit" =>
+                    {
+                        break
+                    }
+                    Ok(query) => {
+                        let _ = rl.add_history_entry(query.as_str());
+                        exec_search(vec![query], &mut config, &default_config, no_color);
+                    }
+                    Err(ReadlineError::Interrupted) => {
+                        println!("CTRL-C");
+                        break;
+                    }
+                    Err(ReadlineError::Eof) => {
+                        println!("CTRL-D");
+                        break;
+                    }
+                    Err(err) => {
+                        let err = format!("{:?}", err);
+                        error_message("input", &err);
+                        break;
                     }
                 }
             },
@@ -162,8 +176,7 @@ fn main() -> ExitCode {
             }
         }
     } else {
-        let query = args.join(" ");
-        exit_value = Some(exec_search(query, &mut config, no_color));
+        exit_value = Some(exec_search(args, &mut config, &default_config, no_color));
     }
 
     config.save();
@@ -172,9 +185,10 @@ fn main() -> ExitCode {
     if config.check_for_updates.unwrap_or(false) && stdout().is_terminal() {
         let name = env!("CARGO_PKG_NAME");
         let version = env!("CARGO_PKG_VERSION");
-        let informer = update_informer::new(registry::Crates, name, version).interval(Duration::from_secs(60 * 60 * 24));
+        let informer = update_informer::new(registry::Crates, name, version)
+            .interval(Duration::from_secs(60 * 60 * 24));
 
-        if let Some(version) = informer.check_version().ok().flatten()  {
+        if let Some(version) = informer.check_version().ok().flatten() {
             println!("\nNew version is available! : {}", version);
         }
     }
@@ -186,9 +200,9 @@ fn main() -> ExitCode {
     ExitCode::SUCCESS
 }
 
-fn exec_search(query: String, config: &mut Config, no_color: bool) -> u8 {
+fn exec_search(query: Vec<String>, config: &mut Config, default_config: &Config, no_color: bool) -> u8 {
     let mut p = Parser::new();
-    let query = p.parse(&query, config.debug);
+    let query = p.parse(query, config.debug);
 
     if config.debug {
         dbg!(&query);
@@ -199,21 +213,24 @@ fn exec_search(query: String, config: &mut Config, no_color: bool) -> u8 {
             let is_terminal = stdout().is_terminal();
             let use_colors = !no_color && is_terminal;
 
-            let mut searcher = Searcher::new(&query, config, use_colors);
+            let mut searcher = Searcher::new(&query, config, default_config, use_colors);
             searcher.list_search_results().unwrap();
 
             let error_count = searcher.error_count;
             match error_count {
                 0 => 0,
-                _ => 1
+                _ => 1,
             }
-        },
-        Err(err) => { error_message("query", &err); 2 }
+        }
+        Err(err) => {
+            error_message("query", &err);
+            2
+        }
     }
 }
 
 fn short_usage_info(no_color: bool) {
-    const VERSION: &'static str = env!("CARGO_PKG_VERSION");
+    const VERSION: &str = env!("CARGO_PKG_VERSION");
 
     print!("fselect ");
 
@@ -228,7 +245,11 @@ fn short_usage_info(no_color: bool) {
     if no_color {
         println!("https://github.com/jhspetersson/fselect");
     } else {
-        println!("{}", Cyan.underline().paint("https://github.com/jhspetersson/fselect"));
+        println!(
+            "{}",
+            Cyan.underline()
+                .paint("https://github.com/jhspetersson/fselect")
+        );
     }
 
     println!();
@@ -236,26 +257,54 @@ fn short_usage_info(no_color: bool) {
 }
 
 fn help_hint() {
-    println!("
-For more detailed instructions please refer to the URL above or run fselect --help");
+    println!(
+        "
+For more detailed instructions please refer to the URL above or run fselect --help"
+    );
 }
 
-fn usage_info(config: Config, no_color: bool) {
+fn usage_info(config: Config, default_config: Config, no_color: bool) {
     short_usage_info(no_color);
 
-    let is_archive = config.is_archive.join(", ");
-    let is_audio = config.is_audio.join(", ");
-    let is_book = config.is_book.join(", ");
-    let is_doc = config.is_doc.join(", ");
-    let is_image = config.is_image.join(", ");
-    let is_source = config.is_source.join(", ");
-    let is_video = config.is_video.join(", ");
+    let is_archive = config
+        .is_archive
+        .unwrap_or(default_config.is_archive.unwrap())
+        .join(", ");
+    let is_audio = config
+        .is_audio
+        .unwrap_or(default_config.is_audio.unwrap())
+        .join(", ");
+    let is_book = config
+        .is_book
+        .unwrap_or(default_config.is_book.unwrap())
+        .join(", ");
+    let is_doc = config
+        .is_doc
+        .unwrap_or(default_config.is_doc.unwrap())
+        .join(", ");
+    let is_font = config
+        .is_font
+        .unwrap_or(default_config.is_font.unwrap())
+        .join(", ");
+    let is_image = config
+        .is_image
+        .unwrap_or(default_config.is_image.unwrap())
+        .join(", ");
+    let is_source = config
+        .is_source
+        .unwrap_or(default_config.is_source.unwrap())
+        .join(", ");
+    let is_video = config
+        .is_video
+        .unwrap_or(default_config.is_video.unwrap())
+        .join(", ");
 
     println!("
 Files Detected as Archives: {is_archive}
 Files Detected as Audio: {is_audio}
 Files Detected as Book: {is_book}
 Files Detected as Document: {is_doc}
+Files Detected as Fonts: {is_font}
 Files Detected as Image: {is_image}
 Files Detected as Source Code: {is_source}
 Files Detected as Video: {is_video}
