@@ -1,37 +1,34 @@
 #[cfg(target_os = "linux")]
 pub(crate) mod capabilities;
 mod datetime;
+pub mod dimensions;
+pub mod duration;
 mod glob;
 pub(crate) mod japanese;
 mod top_n;
 mod wbuf;
-pub mod dimensions;
-pub mod duration;
 
 use std::cmp::Ordering;
 use std::collections::HashMap;
 use std::fmt::Display;
 use std::fs;
 use std::fs::canonicalize;
+use std::fs::symlink_metadata;
 use std::fs::DirEntry;
 use std::fs::File;
 use std::fs::Metadata;
-use std::fs::symlink_metadata;
 use std::io;
-use std::io::{BufReader, BufRead};
 use std::io::Read;
+use std::io::{BufRead, BufReader};
 use std::path::Path;
 use std::path::PathBuf;
 use std::rc::Rc;
-
+use std::sync::LazyLock;
 use chrono::{Datelike, Local, Timelike};
 use mp3_metadata::MP3Metadata;
 use regex::Regex;
 use sha1::Digest;
 
-use crate::expr::Expr;
-#[cfg(windows)]
-use crate::mode;
 pub use self::datetime::format_date;
 pub use self::datetime::format_datetime;
 pub use self::datetime::parse_datetime;
@@ -41,11 +38,17 @@ pub use self::glob::convert_like_to_pattern;
 pub use self::glob::is_glob;
 pub use self::top_n::TopN;
 pub use self::wbuf::WritableBuffer;
+use crate::expr::Expr;
+#[cfg(windows)]
+use crate::mode;
 pub use dimensions::Dimensions;
 pub use duration::Duration;
 
 #[derive(Debug, Clone, PartialEq, Eq, PartialOrd)]
-pub struct Criteria<T> where T: Display + ToString {
+pub struct Criteria<T>
+where
+    T: Display + ToString,
+{
     fields: Rc<Vec<Expr>>,
     /// Values of current row to sort with, placed in order of significance.
     values: Vec<T>,
@@ -54,16 +57,26 @@ pub struct Criteria<T> where T: Display + ToString {
     orderings: Rc<Vec<bool>>,
 }
 
-impl<T> Criteria<T> where T: Display {
+impl<T> Criteria<T>
+where
+    T: Display,
+{
     pub fn new(fields: Rc<Vec<Expr>>, values: Vec<T>, orderings: Rc<Vec<bool>>) -> Criteria<T> {
         debug_assert_eq!(fields.len(), values.len());
         debug_assert_eq!(values.len(), orderings.len());
 
-        Criteria { fields, values, orderings }
+        Criteria {
+            fields,
+            values,
+            orderings,
+        }
     }
 
     #[inline]
-    fn cmp_at(&self, other: &Self, i: usize) -> Ordering where T: Ord {
+    fn cmp_at(&self, other: &Self, i: usize) -> Ordering
+    where
+        T: Ord,
+    {
         let field = &self.fields[i];
         let comparison;
         if field.contains_numeric() {
@@ -74,47 +87,59 @@ impl<T> Criteria<T> where T: Display {
             comparison = self.cmp_at_direct(other, i);
         }
 
-        if self.orderings[i] { comparison } else { comparison.reverse() }
-    }
-
-    #[inline]
-    fn cmp_at_direct(&self, other: &Self, i: usize) -> Ordering where T: Ord {
-        if self.values[i] < other.values[i] {
-            Ordering::Less
-        } else if self.values[i] > other.values[i] {
-            Ordering::Greater
+        if self.orderings[i] {
+            comparison
         } else {
-            Ordering::Equal
+            comparison.reverse()
         }
     }
 
     #[inline]
-    fn cmp_at_numbers(&self, other: &Self, i: usize) -> Ordering where T: Ord {
+    fn cmp_at_direct(&self, other: &Self, i: usize) -> Ordering
+    where
+        T: Ord,
+    {
+        self.values[i].cmp(&other.values[i])
+    }
+
+    #[inline]
+    fn cmp_at_numbers(&self, other: &Self, i: usize) -> Ordering
+    where
+        T: Ord,
+    {
         let a = parse_filesize(&self.values[i].to_string()).unwrap_or(0);
         let b = parse_filesize(&other.values[i].to_string()).unwrap_or(0);
 
-        if a < b {
-            Ordering::Less
-        } else if a > b {
-            Ordering::Greater
-        } else {
-            Ordering::Equal
-        }
+        a.cmp(&b)
     }
 
     #[inline]
-    fn cmp_at_datetimes(&self, other: &Self, i: usize) -> Ordering where T: Ord {
-        let default = Local::now().naive_local().with_year(1970).unwrap().with_month(1).unwrap().with_day(1).unwrap().with_hour(0).unwrap().with_minute(0).unwrap().with_second(0).unwrap();
-        let a = parse_datetime(&self.values[i].to_string()).unwrap_or((default, default)).0;
-        let b = parse_datetime(&other.values[i].to_string()).unwrap_or((default, default)).0;
+    fn cmp_at_datetimes(&self, other: &Self, i: usize) -> Ordering
+    where
+        T: Ord,
+    {
+        let default = Local::now()
+            .naive_local()
+            .with_year(1970)
+            .unwrap()
+            .with_month(1)
+            .unwrap()
+            .with_day(1)
+            .unwrap()
+            .with_hour(0)
+            .unwrap()
+            .with_minute(0)
+            .unwrap()
+            .with_second(0)
+            .unwrap();
+        let a = parse_datetime(&self.values[i].to_string())
+            .unwrap_or((default, default))
+            .0;
+        let b = parse_datetime(&other.values[i].to_string())
+            .unwrap_or((default, default))
+            .0;
 
-        if a < b {
-            Ordering::Less
-        } else if a > b {
-            Ordering::Greater
-        } else {
-            Ordering::Equal
-        }
+        a.cmp(&b)
     }
 }
 
@@ -157,7 +182,7 @@ pub fn error_exit(source: &str, description: &str) -> ! {
 pub fn get_extension(s: &str) -> String {
     match Path::new(s).extension() {
         Some(ext) => ext.to_string_lossy().to_string(),
-        None => String::new()
+        None => String::new(),
     }
 }
 
@@ -168,82 +193,79 @@ pub fn parse_filesize(s: &str) -> Option<u64> {
     if length > 1 && string.ends_with("k") {
         return match &string[..(length - 1)].parse::<f64>() {
             Ok(size) => Some((*size * 1024.0) as u64),
-            _ => None
-        }
+            _ => None,
+        };
     }
 
     if length > 2 && string.ends_with("kb") {
         return match &string[..(length - 2)].parse::<f64>() {
             Ok(size) => Some((*size * 1000.0) as u64),
-            _ => None
-        }
+            _ => None,
+        };
     }
 
     if length > 3 && string.ends_with("kib") {
         return match &string[..(length - 3)].parse::<f64>() {
             Ok(size) => Some((*size * 1024.0) as u64),
-            _ => None
-        }
+            _ => None,
+        };
     }
 
     if length > 1 && string.ends_with("m") {
         return match &string[..(length - 1)].parse::<f64>() {
             Ok(size) => Some((*size * 1024.0 * 1024.0) as u64),
-            _ => None
-        }
+            _ => None,
+        };
     }
 
     if length > 2 && string.ends_with("mb") {
         return match &string[..(length - 2)].parse::<f64>() {
             Ok(size) => Some((*size * 1000.0 * 1000.0) as u64),
-            _ => None
-        }
+            _ => None,
+        };
     }
 
     if length > 3 && string.ends_with("mib") {
         return match &string[..(length - 3)].parse::<f64>() {
             Ok(size) => Some((*size * 1024.0 * 1024.0) as u64),
-            _ => None
-        }
+            _ => None,
+        };
     }
 
     if length > 1 && string.ends_with("g") {
         return match &string[..(length - 1)].parse::<f64>() {
             Ok(size) => Some((*size * 1024.0 * 1024.0 * 1024.0) as u64),
-            _ => None
-        }
+            _ => None,
+        };
     }
 
     if length > 2 && string.ends_with("gb") {
         return match &string[..(length - 2)].parse::<f64>() {
             Ok(size) => Some((*size * 1000.0 * 1000.0 * 1000.0) as u64),
-            _ => None
-        }
+            _ => None,
+        };
     }
 
     if length > 3 && string.ends_with("gib") {
         return match &string[..(length - 3)].parse::<f64>() {
             Ok(size) => Some((*size * 1024.0 * 1024.0 * 1024.0) as u64),
-            _ => None
-        }
+            _ => None,
+        };
     }
 
     if length > 1 && string.ends_with("b") {
         return match &string[..(length - 1)].parse::<u64>() {
             Ok(size) => Some(size * 1),
-            _ => None
-        }
+            _ => None,
+        };
     }
 
-    return match string.parse::<u64>() {
-        Ok(size) => Some(size),
-        _ => None
-    }
+    string.parse::<u64>().ok()
 }
 
-lazy_static! {
-    static ref FILE_SIZE_FORMAT_REGEX: Regex = Regex::new("(%\\.(?P<zeroes>\\d+))?(?P<space>\\s)?(?P<units>\\w+)?").unwrap();
-}
+static FILE_SIZE_FORMAT_REGEX: LazyLock<Regex> = LazyLock::new(|| {
+    Regex::new("(%\\.(?P<zeroes>\\d+))?(?P<space>\\s)?(?P<units>\\w+)?").unwrap()
+});
 
 pub fn format_filesize(size: u64, modifier: &str) -> String {
     let mut modifier = modifier.to_ascii_lowercase();
@@ -251,14 +273,15 @@ pub fn format_filesize(size: u64, modifier: &str) -> String {
     let mut zeroes = -1;
     let mut space = false;
 
-    match FILE_SIZE_FORMAT_REGEX.captures(&modifier) {
-        Some(cap) => {
-            zeroes = cap.name("zeroes").map_or(-1, |m| m.as_str().parse::<i32>().unwrap());
-            space = cap.name("space").map_or(false, |m| m.as_str() == " ");
-            modifier = cap.name("units").map_or(String::from(""), |m| m.as_str().to_string());
-        },
-        _ => {}
-    };
+    if let Some(cap) = FILE_SIZE_FORMAT_REGEX.captures(&modifier) {
+        zeroes = cap
+            .name("zeroes")
+            .map_or(-1, |m| m.as_str().parse::<i32>().unwrap());
+        space = cap.name("space").map_or(false, |m| m.as_str() == " ");
+        modifier = cap
+            .name("units")
+            .map_or(String::from(""), |m| m.as_str().to_string());
+    }
 
     let fixed_at;
     let mut format;
@@ -291,72 +314,72 @@ pub fn format_filesize(size: u64, modifier: &str) -> String {
         "b" | "byte" => {
             fixed_at = Some(humansize::FixedAt::Base);
             format = humansize::BINARY;
-        },
+        }
         "k" | "kib" => {
             fixed_at = Some(humansize::FixedAt::Kilo);
             format = humansize::BINARY;
             if zeroes == -1 {
                 zeroes = 0;
             }
-        },
+        }
         "kb" => {
             fixed_at = Some(humansize::FixedAt::Kilo);
             format = humansize::DECIMAL;
             if zeroes == -1 {
                 zeroes = 0;
             }
-        },
+        }
         "m" | "mib" => {
             fixed_at = Some(humansize::FixedAt::Mega);
             format = humansize::BINARY;
             if zeroes == -1 {
                 zeroes = 0;
             }
-        },
+        }
         "mb" => {
             fixed_at = Some(humansize::FixedAt::Mega);
             format = humansize::DECIMAL;
             if zeroes == -1 {
                 zeroes = 0;
             }
-        },
+        }
         "g" | "gib" => {
             fixed_at = Some(humansize::FixedAt::Giga);
             format = humansize::BINARY;
-        },
+        }
         "gb" => {
             fixed_at = Some(humansize::FixedAt::Giga);
             format = humansize::DECIMAL;
-        },
+        }
         "t" | "tib" => {
             fixed_at = Some(humansize::FixedAt::Tera);
             format = humansize::BINARY;
-        },
+        }
         "tb" => {
             fixed_at = Some(humansize::FixedAt::Tera);
             format = humansize::DECIMAL;
-        },
+        }
         "p" | "pib" => {
             fixed_at = Some(humansize::FixedAt::Peta);
             format = humansize::BINARY;
-        },
+        }
         "pb" => {
             fixed_at = Some(humansize::FixedAt::Peta);
             format = humansize::DECIMAL;
-        },
+        }
         "e" | "eib" => {
             fixed_at = Some(humansize::FixedAt::Exa);
             format = humansize::BINARY;
-        },
+        }
         "eb" => {
             fixed_at = Some(humansize::FixedAt::Exa);
             format = humansize::DECIMAL;
-        },
+        }
         "" => {
             fixed_at = None;
             format = humansize::BINARY;
-        },
-        _ => error_exit("Unknown file size modifier", modifier.as_str())
+        }
+        _ => error_exit("Unknown file size modifier", modifier.as_str()),
     };
 
     if zeroes == -1 {
@@ -376,8 +399,7 @@ pub fn format_filesize(size: u64, modifier: &str) -> String {
         .decimal_places(zeroes as usize)
         .space_after_value(space);
 
-    let mut result = humansize::format_size(size, format_options)
-        .replace("kB", "KB");
+    let mut result = humansize::format_size(size, format_options).replace("kB", "KB");
 
     if short_units {
         result = result
@@ -398,7 +420,7 @@ pub fn str_to_bool(val: &str) -> Option<bool> {
     match str_val.as_str() {
         "true" | "1" | "yes" | "y" => Some(true),
         "false" | "0" | "no" | "n" => Some(false),
-        _ => None
+        _ => None,
     }
 }
 
@@ -406,7 +428,7 @@ pub fn capitalize(s: &str) -> String {
     let mut c = s.chars();
     match c.next() {
         Some(f) => f.to_uppercase().collect::<String>() + c.as_str(),
-        None => String::new()
+        None => String::new(),
     }
 }
 
@@ -414,7 +436,7 @@ pub fn parse_unix_filename(s: &str) -> &str {
     let last_slash = s.rfind('/');
     match last_slash {
         Some(idx) => &s[idx..],
-        _ => s
+        _ => s,
     }
 }
 
@@ -423,7 +445,7 @@ pub fn has_extension(file_name: &str, extensions: &Vec<String>) -> bool {
 
     for ext in extensions {
         if s.ends_with(ext) {
-            return true
+            return true;
         }
     }
 
@@ -435,29 +457,27 @@ pub fn looks_like_regexp(s: &str) -> bool {
 }
 
 pub fn is_text_mime(mime: &str) -> bool {
-    mime.starts_with("text/") ||
-    mime.contains("+xml") ||
-    mime.contains("-xml") ||
-    mime.eq("application/x-awk") ||
-    mime.eq("application/x-perl") ||
-    mime.eq("application/x-php") ||
-    mime.eq("application/x-ruby") ||
-    mime.eq("application/x-shellscript")
+    mime.starts_with("text/")
+        || mime.contains("+xml")
+        || mime.contains("-xml")
+        || mime.eq("application/x-awk")
+        || mime.eq("application/x-perl")
+        || mime.eq("application/x-php")
+        || mime.eq("application/x-ruby")
+        || mime.eq("application/x-shellscript")
 }
 
 pub fn canonical_path(path_buf: &PathBuf) -> Result<String, String> {
     match canonicalize(path_buf) {
         Ok(path) => Ok(format_absolute_path(&path)),
-        Err(err) => {
-            match err.to_string().starts_with("Incorrect function.") {
-                true => Ok(format_absolute_path(&path_buf)),
-                _ => Err(err.to_string())
-            }
-        }
+        Err(err) => match err.to_string().starts_with("Incorrect function.") {
+            true => Ok(format_absolute_path(path_buf)),
+            _ => Err(err.to_string()),
+        },
     }
 }
 
-pub fn format_absolute_path(path_buf: &PathBuf) -> String {
+pub fn format_absolute_path(path_buf: &Path) -> String {
     let path = format!("{}", path_buf.to_string_lossy());
 
     #[cfg(windows)]
@@ -469,7 +489,7 @@ pub fn format_absolute_path(path_buf: &PathBuf) -> String {
 pub fn get_metadata(entry: &DirEntry, follow_symlinks: bool) -> Option<Metadata> {
     let metadata = match follow_symlinks {
         false => symlink_metadata(entry.path()),
-        true => fs::metadata(entry.path())
+        true => fs::metadata(entry.path()),
     };
 
     if let Ok(metadata) = metadata {
@@ -482,7 +502,7 @@ pub fn get_metadata(entry: &DirEntry, follow_symlinks: bool) -> Option<Metadata>
 pub fn get_mp3_metadata(entry: &DirEntry) -> Option<MP3Metadata> {
     match mp3_metadata::read_from_file(entry.path()) {
         Ok(mp3_meta) => Some(mp3_meta),
-        _ => None
+        _ => None,
     }
 }
 
@@ -494,13 +514,26 @@ pub fn get_exif_metadata(entry: &DirEntry) -> Option<HashMap<String, String>> {
             for field in reader.fields() {
                 let field_tag = format!("{}", field.tag);
                 match field.value {
-                    exif::Value::Rational(ref vec) if !vec.is_empty() && (field_tag.eq("GPSLongitude") || field_tag.eq("GPSLatitude") || field_tag.eq("GPSAltitude")) => {
-                        exif_info.insert(field_tag, vec.iter().map(|r| (r.num / r.denom).to_string()).collect::<Vec<String>>().join(";"));
-                    },
-                    exif::Value::Ascii(ref vec) if !vec.is_empty() => if let Ok(str_value) = std::str::from_utf8(&vec[0]) {
-                        exif_info.insert(field_tag, str_value.to_string());
-                    },
-                    _ =>  {
+                    exif::Value::Rational(ref vec)
+                        if !vec.is_empty()
+                            && (field_tag.eq("GPSLongitude")
+                                || field_tag.eq("GPSLatitude")
+                                || field_tag.eq("GPSAltitude")) =>
+                    {
+                        exif_info.insert(
+                            field_tag,
+                            vec.iter()
+                                .map(|r| (r.num / r.denom).to_string())
+                                .collect::<Vec<String>>()
+                                .join(";"),
+                        );
+                    }
+                    exif::Value::Ascii(ref vec) if !vec.is_empty() => {
+                        if let Ok(str_value) = std::str::from_utf8(&vec[0]) {
+                            exif_info.insert(field_tag, str_value.to_string());
+                        }
+                    }
+                    _ => {
                         exif_info.insert(field_tag, field.value.display_as(field.tag).to_string());
                     }
                 }
@@ -523,7 +556,12 @@ pub fn get_exif_metadata(entry: &DirEntry) -> Option<HashMap<String, String>> {
             }
 
             if exif_info.contains_key("GPSAltitude") && exif_info.contains_key("GPSAltitudeRef") {
-                let mut altitude = exif_info.get("GPSAltitude").unwrap().to_string().parse::<f32>().unwrap_or(0.0);
+                let mut altitude = exif_info
+                    .get("GPSAltitude")
+                    .unwrap()
+                    .to_string()
+                    .parse::<f32>()
+                    .unwrap_or(0.0);
                 let altitude_ref = exif_info.get("GPSAltitudeRef").unwrap().to_string();
                 if altitude_ref.eq("1") {
                     altitude = -altitude;
@@ -539,9 +577,11 @@ pub fn get_exif_metadata(entry: &DirEntry) -> Option<HashMap<String, String>> {
 }
 
 fn parse_location_string(s: String, location_ref: String, modifier_value: &str) -> Result<f32, ()> {
-    let parts = s.split(";").map(|p| p.to_string()).collect::<Vec<String>>();
+    let parts = s.split(';').map(|p| p.to_string()).collect::<Vec<String>>();
     if parts.len() == 3 {
-        let mut coord = parts[0].parse::<f32>().unwrap_or(0.0) + parts[1].parse::<f32>().unwrap_or(0.0) / 60.0 + parts[2].parse::<f32>().unwrap_or(0.0) / 3660.0;
+        let mut coord = parts[0].parse::<f32>().unwrap_or(0.0)
+            + parts[1].parse::<f32>().unwrap_or(0.0) / 60.0
+            + parts[2].parse::<f32>().unwrap_or(0.0) / 3660.0;
         if location_ref.eq(modifier_value) {
             coord = -coord;
         }
@@ -549,7 +589,7 @@ fn parse_location_string(s: String, location_ref: String, modifier_value: &str)
         return Ok(coord);
     }
 
-    return Err(());
+    Err(())
 }
 
 pub fn is_shebang(path: &PathBuf) -> bool {
@@ -557,7 +597,7 @@ pub fn is_shebang(path: &PathBuf) -> bool {
         let mut buf_reader = BufReader::new(file);
         let mut buf = vec![0; 2];
         if buf_reader.read_exact(&mut buf).is_ok() {
-            return buf[0] == 0x23 && buf[1] == 0x21
+            return buf[0] == 0x23 && buf[1] == 0x21;
         }
     }
 
@@ -575,25 +615,25 @@ pub fn is_hidden(file_name: &str, metadata: &Option<Metadata>, archive_mode: boo
     }
 
     #[cfg(unix)]
-        {
-            return file_name.starts_with('.');
-        }
+    {
+        return file_name.starts_with('.');
+    }
 
     #[cfg(windows)]
-        {
-            if let Some(ref metadata) = metadata {
-                return mode::get_mode(metadata).contains("Hidden");
-            }
+    {
+        if let Some(ref metadata) = metadata {
+            return mode::get_mode(metadata).contains("Hidden");
         }
+    }
 
     #[cfg(not(unix))]
-        {
-            false
-        }
+    {
+        false
+    }
 }
 
 pub fn get_line_count(entry: &DirEntry) -> Option<usize> {
-    if let Ok(file) = File::open(&entry.path()) {
+    if let Ok(file) = File::open(entry.path()) {
         let mut reader = BufReader::with_capacity(1024 * 32, file);
         let mut count = 0;
 
@@ -604,7 +644,7 @@ pub fn get_line_count(entry: &DirEntry) -> Option<usize> {
                         break;
                     }
 
-                    count += bytecount::count(&buf, b'\n');
+                    count += bytecount::count(buf, b'\n');
                     buf.len()
                 } else {
                     return None;
@@ -621,7 +661,7 @@ pub fn get_line_count(entry: &DirEntry) -> Option<usize> {
 }
 
 pub fn get_sha1_file_hash(entry: &DirEntry) -> String {
-    if let Ok(mut file) = File::open(&entry.path()) {
+    if let Ok(mut file) = File::open(entry.path()) {
         let mut hasher = sha1::Sha1::new();
         if io::copy(&mut file, &mut hasher).is_ok() {
             let hash = hasher.finalize();
@@ -633,7 +673,7 @@ pub fn get_sha1_file_hash(entry: &DirEntry) -> String {
 }
 
 pub fn get_sha256_file_hash(entry: &DirEntry) -> String {
-    if let Ok(mut file) = File::open(&entry.path()) {
+    if let Ok(mut file) = File::open(entry.path()) {
         let mut hasher = sha2::Sha256::new();
         if io::copy(&mut file, &mut hasher).is_ok() {
             let hash = hasher.finalize();
@@ -645,7 +685,7 @@ pub fn get_sha256_file_hash(entry: &DirEntry) -> String {
 }
 
 pub fn get_sha512_file_hash(entry: &DirEntry) -> String {
-    if let Ok(mut file) = File::open(&entry.path()) {
+    if let Ok(mut file) = File::open(entry.path()) {
         let mut hasher = sha2::Sha512::new();
         if io::copy(&mut file, &mut hasher).is_ok() {
             let hash = hasher.finalize();
@@ -657,7 +697,7 @@ pub fn get_sha512_file_hash(entry: &DirEntry) -> String {
 }
 
 pub fn get_sha3_512_file_hash(entry: &DirEntry) -> String {
-    if let Ok(mut file) = File::open(&entry.path()) {
+    if let Ok(mut file) = File::open(entry.path()) {
         let mut hasher = sha3::Sha3_512::new();
         if io::copy(&mut file, &mut hasher).is_ok() {
             let hash = hasher.finalize();
@@ -669,9 +709,9 @@ pub fn get_sha3_512_file_hash(entry: &DirEntry) -> String {
 }
 
 pub fn is_dir_empty(entry: &DirEntry) -> Option<bool> {
-    match fs::read_dir(&entry.path()) {
+    match fs::read_dir(entry.path()) {
         Ok(dir) => Some(!dir.into_iter().any(|_| true)),
-        _ => None
+        _ => None,
     }
 }
 
@@ -795,10 +835,22 @@ mod tests {
         assert_eq!(format_filesize(file_size, "%.2 "), String::from("1.60 MiB"));
         assert_eq!(format_filesize(file_size, "%.2 d"), String::from("1.68 MB"));
         assert_eq!(format_filesize(file_size, "%.2 c"), String::from("1.60 MB"));
-        assert_eq!(format_filesize(file_size, "%.2 k"), String::from("1638.79 KiB"));
-        assert_eq!(format_filesize(file_size, "%.2 ck"), String::from("1638.79 KB"));
-        assert_eq!(format_filesize(file_size, "%.0 ck"), String::from("1639 KB"));
-        assert_eq!(format_filesize(file_size, "%.0 kb"), String::from("1678 KB"));
+        assert_eq!(
+            format_filesize(file_size, "%.2 k"),
+            String::from("1638.79 KiB")
+        );
+        assert_eq!(
+            format_filesize(file_size, "%.2 ck"),
+            String::from("1638.79 KB")
+        );
+        assert_eq!(
+            format_filesize(file_size, "%.0 ck"),
+            String::from("1639 KB")
+        );
+        assert_eq!(
+            format_filesize(file_size, "%.0 kb"),
+            String::from("1678 KB")
+        );
         assert_eq!(format_filesize(file_size, "%.0kb"), String::from("1678KB"));
         assert_eq!(format_filesize(file_size, "%.0s"), String::from("2M"));
         assert_eq!(format_filesize(file_size, "%.0 s"), String::from("2 M"));
